@@ -1,8 +1,5 @@
 package Org::To::Base;
 
-our $DATE = '2020-09-11'; # DATE
-our $VERSION = '0.233'; # VERSION
-
 use 5.010001;
 use Log::ger;
 
@@ -10,6 +7,11 @@ use List::Util qw(first);
 use Moo;
 use experimental 'smartmatch';
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-01-21'; # DATE
+our $DIST = 'Org-To-HTML'; # DIST
+our $VERSION = '0.234'; # VERSION
+
 has include_tags => (is => 'rw');
 has exclude_tags => (is => 'rw');
 
@@ -158,7 +160,7 @@ Org::To::Base - Base class for Org exporters
 
 =head1 VERSION
 
-This document describes version 0.233 of Org::To::Base (from Perl distribution Org-To-HTML), released on 2020-09-11.
+This document describes version 0.234 of Org::To::Base (from Perl distribution Org-To-HTML), released on 2022-01-21.
 
 =head1 SYNOPSIS
 
@@ -231,6 +233,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-To-HTM
 
 Source repository is at L<https://github.com/perlancar/perl-Org-To-HTML>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Org-To-HTML>
@@ -239,15 +269,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
